@@ -27,9 +27,6 @@ def get_name():
 
 class DecimalClock(clock.Clock):
     def draw_clock(self):
-        self.context.set_font_size(int(self.text_scaling * 45))
-        self.context.move_to(0, 35)
-
         h = self.time.hour
         if self.twelve_hour_mode :
             abrv = "AM"
@@ -50,46 +47,21 @@ class DecimalClock(clock.Clock):
         if self.show_seconds :
             text = text + ":" + str(self.time.second).zfill(2)
         
-        if (self.font_name is not None) and self.font_name.startswith("Klingon") :
-            text = clock.to_klingon_digits(text)
-            if self.twelve_hour_mode :
-                abrv = clock.to_klingon_text(abrv)
-
-        self.context.text_path(text)
-        if self.fill :
-            self.context.fill()
-        else :
-            self.context.stroke()
+        self.draw_text(text)
 
         if self.twelve_hour_mode :
-            self.context.set_font_size(int(self.text_scaling * 20))
-            self.context.move_to(self.text_width, 35)
-            
-            self.context.text_path(abrv)
-            self.context.stroke()
+            self.draw_text(abrv, 20, self.text_width)
 
     def resize(self):
-        factor = 1.1
-        abrv = "AM"
-        self.context.set_font_size(int(self.text_scaling * 45))
-      
         if self.show_seconds :
-            text = "00:00:00"
+            text = "22:22:22"
         else:
-            text = "00:00"
+            text = "22:22"
 
-        if (self.font_name is not None) and self.font_name.startswith("Klingon") :
-            text = clock.to_klingon_digits(text)
-            abrv = clock.to_klingon_text(abrv)
-            factor = 1.05
-
-        self.text_width = self.context.text_extents(text)[2]
-        self.text_width *= factor
+        self.text_width = self.calculate_text_width(text)
 
         if self.twelve_hour_mode :
-            self.context.set_font_size(int(self.text_scaling * 20))
-            self.abrv_width = self.context.text_extents(abrv)[2]
-            self.abrv_width *= factor
+            self.abrv_width = self.calculate_text_width("AM", 20)
         else :
             self.abrv_width = 0
 
